Model YAML:

.. literalinclude:: /../../cis_interface/examples/rpc_lesson2/server_python.yml
   :language: yaml
   :linenos:

.. literalinclude:: /../../cis_interface/examples/rpc_lesson2/client_python.yml
   :language: yaml
   :linenos:


(`Example in other languages <examples/rpc_lesson2.html>`__)
